@@ -8,6 +8,8 @@
 //===----------------------------------------------------------------------===//
 
 #include "Logger.h"
+#include "llvm/Support/raw_ostream.h"
+#include <mutex>
 
 namespace clang {
 namespace clangd {
@@ -23,10 +25,23 @@ LoggingSession::LoggingSession(clangd::Logger &Instance) {
 
 LoggingSession::~LoggingSession() { L = nullptr; }
 
-void log(const Context &Ctx, const llvm::Twine &Message) {
-  if (!L)
-    return;
-  L->log(Ctx, Message);
+void detail::log(Logger::Level Level,
+                 const llvm::formatv_object_base &Message) {
+  if (L)
+    L->log(Level, Message);
+  else {
+    static std::mutex Mu;
+    std::lock_guard<std::mutex> Guard(Mu);
+    llvm::errs() << Message << "\n";
+  }
+}
+
+const char *detail::debugType(const char *Filename) {
+  if (const char *Slash = strrchr(Filename, '/'))
+    return Slash + 1;
+  if (const char *Backslash = strrchr(Filename, '\\'))
+    return Backslash + 1;
+  return Filename;
 }
 
 } // namespace clangd
